@@ -18,7 +18,7 @@
 from __future__ import annotations
 
 from functools import cached_property
-from typing import Iterable
+from typing import TYPE_CHECKING, Iterable
 
 from airflow.exceptions import AirflowOptionalProviderFeatureException
 
@@ -29,13 +29,15 @@ except ImportError:
         "Failed to import BaseNotifier. This feature is only available in Airflow versions >= 2.6.0"
     )
 
-from apprise import AppriseConfig, NotifyFormat, NotifyType
 
 from airflow.providers.apprise.hooks.apprise import AppriseHook
 
+if TYPE_CHECKING:
+    from apprise import AppriseConfig, NotifyFormat, NotifyType
+
 
 class AppriseNotifier(BaseNotifier):
-    """
+    r"""
     Apprise BaseNotifier.
 
     :param body: Specify the message body
@@ -47,10 +49,10 @@ class AppriseNotifier(BaseNotifier):
     :param tag: Specify one or more tags to filter which services to notify
     :param attach: Specify one or more file attachment locations
     :param interpret_escapes: Enable interpretation of backslash escapes. For example, this would convert
-        sequences such as \\n and \\r to their respected ascii new-line and carriage
+        sequences such as \n and \r to their respected ascii new-line and carriage
     :param config: Specify one or more configuration
     :param apprise_conn_id: connection that has Apprise configs setup
-    """  # noqa: D301
+    """
 
     template_fields = ("body", "title", "tag", "attach")
 
